${TITLE}

**Date**: |today| **Version**: |Release|

.. toctree::
   :maxdepth: 2
   :caption: Contents:


***
API
***

.. include:: modules.rst


******************
Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
